package com.mints.goodmoney.ui.adapter

import android.content.Context
import android.graphics.Color
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.ImageView
import android.widget.ProgressBar
import android.widget.TextView
import androidx.recyclerview.widget.RecyclerView
import com.mints.goodmoney.R
import com.mints.goodmoney.mvp.model.TaskBean
import com.mints.goodmoney.ui.adapter.listener.OnItemChildClickListener
import com.mints.goodmoney.ui.adapter.listener.OnItemClickListener

class MainMyAdapter(context: Context, taskData: MutableList<TaskBean>) : RecyclerView.Adapter<RecyclerView.ViewHolder>() {

    companion object {
        const val TASK_TYPE_HOME = 0x00000001
        const val TASK_TYPE_INVITE = 0x00000002
        const val TASK_TYPE_VIDEO = 0x00000003
        const val TASK_TYPE_GAME = 0x00000004
        const val TASK_TYPE_FICTION = 0x00000005
        const val TASK_TYPE_DEMO = 0x00000006
    }

    private var mContext: Context = context
    private var taskData: List<TaskBean>? = taskData

    private var mOnItemClickListener: OnItemClickListener? = null
    private var mOnItemChildClickListener: OnItemChildClickListener? = null

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        val inflater: LayoutInflater = LayoutInflater.from(mContext)
        return TaskHolder(inflater.inflate(R.layout.item_fragment_main_my_task, parent, false))
    }

    override fun getItemCount(): Int {
        return if (taskData == null) {
            0
        } else {
            taskData!!.size
        }
    }

    override fun onBindViewHolder(holder: RecyclerView.ViewHolder, position: Int) {
        holder.itemView.setOnClickListener {
            mOnItemClickListener?.onItemClick(it, position)
        }
        taskData?.let {
            val taskBean = it[position]
            if (holder is TaskHolder) {
                holder.itemTaskClick.setOnClickListener { it2 ->
                    mOnItemChildClickListener?.onItemChildClick(it2, position)
                }
                holder.itemTaskTitle.text = taskBean.title
                holder.itemTaskContent.text = taskBean.title
//                holder.itemTaskImg.setImageDrawable(mContext.resources.getDrawable(taskBean.imageSrc))
                if (taskBean.btnStr.isEmpty()) {
                    holder.itemTaskClick.visibility = View.GONE
                } else {
                    holder.itemTaskClick.visibility = View.VISIBLE
                    holder.itemTaskClick.text = taskBean.btnStr
                    holder.itemTaskPb.progress = 10
                    when (taskBean.btnStr) {
                        "立即领取" -> {
                            holder.itemTaskClick.setBackgroundResource(R.drawable.shape_btn_orange_complete)
                            holder.itemTaskClick.setTextColor(Color.WHITE)
                        }
                        "已完成" -> {
                            holder.itemTaskClick.setBackgroundResource(R.drawable.shape_btn_gury)
                            holder.itemTaskClick.setTextColor(Color.WHITE)
                        }
                        else -> {
                            holder.itemTaskClick.setBackgroundResource(R.drawable.shape_btn_orange)
                            holder.itemTaskClick.setTextColor(mContext.resources.getColor(R.color.my_color_orange))
                        }
                    }
                }
                if (taskBean.progressStr.isEmpty()) {
                    holder.itemTaskProgress.visibility = View.GONE
                } else {
                    holder.itemTaskProgress.visibility = View.VISIBLE
                    holder.itemTaskProgress.text = taskBean.progressStr
                }


            }
        }

    }

    private inner class TaskHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {
//        val itemTaskImg: ImageView = itemView.findViewById(R.id.item_title_img)
        val itemTaskTitle: TextView = itemView.findViewById(R.id.item_task_title)
        val itemTaskProgress: TextView = itemView.findViewById(R.id.item_task_progress)
        val itemTaskClick: TextView = itemView.findViewById(R.id.item_task_click)
        val itemTaskContent: TextView = itemView.findViewById(R.id.item_task_content)
        val itemTaskPb: ProgressBar = itemView.findViewById(R.id.item_task_pb)
    }

    fun setOnItemChildClickListener(listener: OnItemChildClickListener) {
        mOnItemChildClickListener = listener
    }


}